qcacld-3.0: Rename enable_range_ext to range_ext

IOCTL cannot handle names more than 15 character long.
So rename enable_range_ext to range_ext.

Change-Id: I9134cc76357f1cd6e175581fa072a8cbb67c19e4
CRs-Fixed: 2146728
diff --git a/core/hdd/src/wlan_hdd_hostapd.c b/core/hdd/src/wlan_hdd_hostapd.c
index a77aa11..65d63b7 100644
--- a/core/hdd/src/wlan_hdd_hostapd.c
+++ b/core/hdd/src/wlan_hdd_hostapd.c
@@ -6021,7 +6021,7 @@
 	{
 		QCASAP_PARAM_RANGE_EXT,
 		IW_PRIV_TYPE_INT | IW_PRIV_SIZE_FIXED | 1,
-		0, "enable_range_ext"
+		0, "range_ext"
 	}
 	,
 	{	QCSAP_SET_DEFAULT_AMPDU,
diff --git a/core/hdd/src/wlan_hdd_wext.c b/core/hdd/src/wlan_hdd_wext.c
index 145eb1e..9acd327 100644
--- a/core/hdd/src/wlan_hdd_wext.c
+++ b/core/hdd/src/wlan_hdd_wext.c
@@ -1077,7 +1077,7 @@
 
 /*
  * <ioctl>
  * enable_range_ext - enable Range extension
  *
  * @INPUT: 0/1
  *
@@ -1085,7 +1085,7 @@
  *
  * This IOCTL enables/disables Range extension.
  *
- * @E.g: iwpriv wlan0 enable_range_ext <0/1>
+ * @E.g: iwpriv wlan0 range_ext <1/0>
  *
  * Supported Feature: STA/SAP
  *
@@ -11981,7 +11981,7 @@
 	{WE_SET_RANGE_EXT,
 	 IW_PRIV_TYPE_INT | IW_PRIV_SIZE_FIXED | 1,
 	 0,
-	 "enable_range_ext"}
+	 "range_ext"}
 	,
 
 	{WLAN_PRIV_SET_FTIES,
@@ -1077,7 +1077,7 @@
 /*
  * <ioctl>
- * enable_range_ext - enable Range extension
+ * range_ext - enable Range extension
  *
  * @INPUT: 0/1